pycocoa.deprecated.Cache2

Package pycocoa :: Module deprecated :: Class Cache2 |
[frames] | no frames]

# Class Cache2

     object --+
              |
           dict --+
                  |
    getters._Cache2 --+
                      |
                     Cache2

DEPRECATED on 2025.02.15, to be removed.

Instance Methods
Inherited from `getters._Cache2`: `__contains__`, `__delitem__`, `__getitem__`, `__init__`, `__setitem__`, `get`, `pop`, `popitem`, `update` Inherited from `dict`: `__cmp__`, `__eq__`, `__ge__`, `__getattribute__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `setdefault`, `values`, `viewitems`, `viewkeys`, `viewvalues` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`, `__subclasshook__`

Class Variables
Inherited from `dict`: `__hash__`

Properties
Inherited from `getters._Cache2`: `dict2`, `limit2` Inherited from `object`: `__class__`